# Spoonful Scientific Library

Spoonful is a Python package meant to handle fairly common tasks encounted in mathematics and physics, such as numerical integration, matrix and linear algebra, and root-finding.

## Installation and Upgrading

I'm still trying to figure that one out, I'll need a second lol.

## Usage

The initial release of Spoonful contains some useful functions such as:

 - Integrator.Simpson -- Integration via Simpson's 1/3 rule
 - Integrator.Trapezoid -- Integration via trapezoidal sums
 - ODE.RK4 -- Numerical integration using Runge Kutta of 4th Order
 - ODE.Coupled_RK4 -- Numerical integration of coupled ODEs using Runge Kutta of 4th Order

## Contributing

If you have an idea you'd like me to implement or catch a bug, let me know and I'll try to send a fix ASAP!

## License

MIT
